@@ -2,7 +2,7 @@ from pandas import DataFrame
 import pandas as pd
 
 from dhlab.api.dhlab_api import document_corpus, get_metadata, evaluate_documents
-
+from typing import Union
 
 class Corpus:
     def __init__(
@@ -39,18 +39,27 @@ class Corpus:
 
         self.size = len(self.corpus)
 
-
+    def __repr__(self) -> str:
+        """
+        Return the string representation of the corpus datafrane
+        """
+        return self.corpus.__repr__()
+    
+    def _repr_html_(self) -> Union[str, None]:
+        """
+        Return the HTML representation of the corpus datafrane
+        """
+        return self.corpus._repr_html_()
+    
 
     def add(self, corpus = None):
         """Add a corpus to existing corpus"""
-        new_corpus = pd.concat([self.corpus, corpus.corpus]).drop_duplicates()
-        self.corpus = new_corpus
+        self.corpus = pd.concat([self.corpus, corpus.corpus]).drop_duplicates().reset_index(drop=True)
         self.size = len(self.corpus)
     
     def extend_from_identifiers(self, identifiers=None):
-        corpus = get_metadata(urnlist(identifiers))
-        self.corpus = pd.concat([self.corpus, corpus]).drop_duplicates()
-        self.size = len(self.corpus)
+        other_corpus = get_metadata(urnlist(identifiers))
+        self.add(other_corpus)
         
     def evaluate_words(self, wordbags = None):
         df = evaluate_documents(wordbags = wordbags, urns = list(self.corpus.urn))
@@ -70,7 +79,6 @@ class Corpus_from_identifiers(Corpus):
         self.corpus = get_metadata(urnlist(identifiers))
         self.size = len(self.corpus)
 
-
 def urnlist(corpus):
     """Try to pull out a list of URNs from corpus"""
 
